@@ -312,6 +312,15 @@ def csr_decoder(isa_yaml, work_dir, bsv, logging=False):
     definefile.write('\n           endcase')
     definefile.write('\n     endfunction')
 
+    definefile.write('''
+
+    function Bool fn_csrbox_access(Bit#(12) csr_addr, Bit#(5) operand, Bit#(2) operation, Bit#(2) prv);
+      Bool write = (operand != 0 || operation=='b01) ? True:False;
+      return ((prv >= csr_addr[9:8]) && !(write && csr_addr[11:10]==2'b11) );
+    endfunction:fn_csrbox_access
+
+''')
+
     definefile.write(end_package_temp)
     definefile.close()
 
